//
// VMime library (http://www.vmime.org)
// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 3 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Linking this library statically or dynamically with other modules is making
// a combined work based on this library.  Thus, the terms and conditions of
// the GNU General Public License cover the whole combination.
//

#ifndef VMIME_UTILITY_URLUTILS_HPP_INCLUDED
#define VMIME_UTILITY_URLUTILS_HPP_INCLUDED


#include "vmime/types.hpp"
#include "vmime/base.hpp"


namespace vmime {
namespace utility {


/** Miscellaneous functions related to URLs.
  */
class VMIME_EXPORT urlUtils {

public:

	/** Encode extended characters in a URL string (ASCII characters
	  * are unmodified, other are encoded as '%' followed by hex code).
	  */
	static const string encode(const string& s);

	/** Decode an hex-encoded URL (see encode()).
	  */
	static const string decode(const string& s);
};


} // utility
} // vmime


#endif // VMIME_UTILITY_URLUTILS_HPP_INCLUDED
